==> django-chamber-0.4.0.tar.gz: django-chamber-0.4.0/chamber/multidomains/auth/middleware.py <==
from django.utils.functional import SimpleLazyObject

from is_core.config import settings as is_core_settings  # pylint: disable=E0401
from is_core.auth_token import utils  # pylint: disable=E0401
from is_core.auth_token.middleware import TokenAuthenticationMiddlewares, get_user  # pylint: disable=E0401
from is_core.auth_token.models import Token  # pylint: disable=E0401
from is_core.auth_token.utils import dont_enforce_csrf_checks  # pylint: disable=E0401
from is_core.utils import header_name_to_django  # pylint: disable=E0401

from chamber import config
from chamber.shortcuts import get_object_or_none


def get_token(request):
    """
    Returns the token model instance associated with the given request token key.
    If no user is retrieved AnonymousToken is returned.
    """
    if (not request.META.get(header_name_to_django(is_core_settings.AUTH_HEADER_NAME)) and
            config.CHAMBER_MULTIDOMAINS_OVERTAKER_AUTH_COOKIE_NAME):
        ovetaker_auth_token = request.COOKIES.get(config.CHAMBER_MULTIDOMAINS_OVERTAKER_AUTH_COOKIE_NAME)
        token = get_object_or_none(Token, key=ovetaker_auth_token, is_active=True)
        if utils.get_user_from_token(token).is_authenticated():
            return token

    return utils.get_token(request)


class MultiDomainsTokenAuthenticationMiddleware(TokenAuthenticationMiddlewares):

    def process_request(self, request):
        """
        Lazy set user and token
        """
        request.token = get_token(request)
        request.user = SimpleLazyObject(lambda: get_user(request))
        request._dont_enforce_csrf_checks = dont_enforce_csrf_checks(request)  # pylint: disable=W0212

==> django-chamber-0.4.9.tar.gz: django-chamber-0.4.9/chamber/multidomains/auth/middleware.py <==
from django.utils.functional import SimpleLazyObject

from auth_token import utils  # pylint: disable=E0401
from auth_token.config import settings as auth_token_settings  # pylint: disable=E0401
from auth_token.middleware import TokenAuthenticationMiddleware, get_user  # pylint: disable=E0401
from auth_token.models import Token  # pylint: disable=E0401
from auth_token.utils import dont_enforce_csrf_checks, header_name_to_django  # pylint: disable=E0401

from chamber import config
from chamber.shortcuts import get_object_or_none


def get_token(request):
    """
    Returns the token model instance associated with the given request token key.
    If no user is retrieved AnonymousToken is returned.
    """
    if (not request.META.get(header_name_to_django(auth_token_settings.HEADER_NAME)) and
            config.CHAMBER_MULTIDOMAINS_OVERTAKER_AUTH_COOKIE_NAME):
        ovetaker_auth_token = request.COOKIES.get(config.CHAMBER_MULTIDOMAINS_OVERTAKER_AUTH_COOKIE_NAME)
        token = get_object_or_none(Token, key=ovetaker_auth_token, is_active=True)
        if utils.get_user_from_token(token).is_authenticated():
            return token

    return utils.get_token(request)


class MultiDomainsTokenAuthenticationMiddleware(TokenAuthenticationMiddleware):

    def process_request(self, request):
        """
        Lazy set user and token
        """
        request.token = get_token(request)
        request.user = SimpleLazyObject(lambda: get_user(request))
        request._dont_enforce_csrf_checks = dont_enforce_csrf_checks(request)  # pylint: disable=W0212
